@@ -1,5 +1,5 @@
 #
-# $Id$
+# $Id: Uniq.pm 4065 2004-11-01 15:38:09Z james $
 #
 
 =head1 NAME
@@ -28,7 +28,7 @@ use base 'Exporter';
 use strict;
 use warnings;
 
-our $VERSION = '0.21.0';
+our $VERSION = '0.11';
 
 # set up exports
 our @EXPORT;
@@ -42,7 +42,8 @@ Exporter::export_ok_tags('all');
 =head2 uniq( { OPTIONS }, ele1, ele2, ..., eleN )
 
 uniq() takes a list of elements and returns the unique elements of the list. 
-Each element may be a scalar value or a reference to a list.
+Each element may be a scalar value or a reference to a list.  List
+references will be flattened before the unique filter is applied.
 
 If the first element is a hash reference it is taken to be a set of options
 that alter the way in which the unique filter is applied.  The keys of the
@@ -56,21 +57,6 @@ If set to a true value, the unique elements of the list will be returned
 sorted.  Perl's default sort will be used unless the B<compare> option is
 also passed.
 
-B<sort> defaults to false.
-
-=item * flatten
-
-If set to a true value, array references in the list will be recursively
-flattened, such that
-
-  ( 'foo', [ [ 'bar' ] ], [ [ [ 'baz', 'quux' ] ] ] )
-
-becomes
-
-  ( 'foo', 'bar', 'baz', 'quux' )
-
-B<flatten> defaults to true.
-
 =item * compare
 
 A code reference that will be used to sort the elements of the list if the
@@ -94,8 +80,6 @@ or a reference to a list of unique elements if called in scalar context.
 
 =cut
 
-my %default_opts = ( sort => 0, flatten => 1 );
-
 sub uniq
 {
 
@@ -104,40 +88,40 @@ sub uniq
     if( ref $_[0] eq 'HASH' ) {
         $opts = shift @_;
     }
-    for my $opt( keys %default_opts ) {
-      unless( defined $opts->{$opt} ) {
-        $opts->{$opt} = $default_opts{$opt};
-      }
-    }
-    
+
     # flatten list references
-    if( $opts->{flatten} ) {
-      my $unwrap;
-      $unwrap = sub { map { 'ARRAY' eq ref $_ ? $unwrap->( @$_ ) : $_ } @_ };
-      @_ = $unwrap->( \@_ );
+    my $i = 0;
+    for( @_ ) {
+        if( 'ARRAY' eq ref $_ ) {
+            splice @_, $i, 1, @$_;
+        }
+        $i++;
     }
     
-    # uniq the elements
-    my @elements;
+    # sort the elements
     my %seen;
     {
         no warnings 'uninitialized';
-        @elements = grep { ! $seen{$_} ++ } @_;
+        @_ = grep { ! $seen{$_} ++ } @_;
     }
     
     # sort before returning if so desired
+    my @elements;
     if( $opts->{sort} ) {
         if( $opts->{compare} ) {
             unless( 'CODE' eq ref $opts->{compare} ) {
                 require Carp;
-                Carp::croak("compare option is not a CODEREF");
+                Carp::croak "compare option is not a CODEREF";
             }
-            @elements = sort { $opts->{compare}->($a,$b) } @elements;
+            @elements = sort { $opts->{compare}->($a,$b) } @_;
         }
         else {
-            @elements = sort @elements;
+            @elements = sort @_;
         }
     }
+    else {
+        @elements = @_;
+    }
     
     # return a list or list ref
     return wantarray ? @elements : \@elements;
@@ -171,8 +155,8 @@ auto-vivified and thus not easily tied to Array::Unique.
 
 =head1 AUTHOR
 
-James FitzGibbon
-<james+perl@nadt.net>
+James FitzGibbon, Primus Telecommunications Canada Inc.
+<jfitzgibbon@primustel.ca>
 
 =head1 CREDITS
 
@@ -186,9 +170,6 @@ Hopefully you do too.
 =head1 COPYRIGHT
 
 Copyright (c) 2004-2008 Primus Telecommunications Canada Inc.
-
-Copyright (c) 2008-2010 James FitzGibbon
-
 All Rights Reserved.
 
 This library is free software; you may use it under the same
